---
title: <span class="badge object-type-scalar"></span> GigaHashesPerSecond
---
# <span class="badge object-type-scalar"></span> GigaHashesPerSecond

Hash rate: gigahashes/sec

## Definition

```python
# Hash rate: gigahashes/sec
GigaHashesPerSecond: typing.Literal["GHs"] = "GHs"
```
